# The Key-value Profile Consistency Identification Dataset

## LICENSE

The dataset is released for academic research only. Any commercial usage please contact <brandenwang@tencent.com> or <shumingshi@tencent.com> for further authorization.

## GUIDPOST
A KvPI data tuple consists of the following elements, as provided in the train/valid/test files:

|  Elements				| Explanations  |
|  ----  					| ----  |
| ID						| A unique identifier for data tuples, numbered consecutively in train, valid, and test. |
| Query					| Input information in a single-turn dialogue. Notice that the speaker on this side is not profiled. |
| Response				| Responses in a single-turn dialogue. It contains attribute related information, but not necessarily related to the response speaker's own attributes.	|
| Profile					| Attribute information of the respondent, including three groups of attributes: *gender*, *location*, and *constellation*.	|
| Domain					| Attribute field to which the dialogue response belongs. Value Mappings: **0**:gender, **1**:location, **2**:constellation.	|
| ConsistencyLabel		| Human annotated labels for consistency relations between Profile and Response, including *Irrelevant*, *Entailed*, and *Contradicted*. For details of the consistency relations please refer to the next section. Value Mappings: **0**:irrelevant, **1**:entailed, **2**:contradicted.	|
| AnnotatedAttributes	| Human-extracted attribute information from the dialogue responses. Different from the given profile under some circumstances.	|
| ProfileSeg				| Linearized key-value profiles. A token is added at the top to aggregate the structure information.	|
| ProfileDependency		| Predefined structure for the key-value structures. For example, 0 1 2 1 4 1 6. Each number corresponds to a word. 0 represents the root node, and other numbers represent the parent node's position of the corresponding word.	|
| ResponseSeg				| The responses are in Chinese, thus we provide the segmented sentences for dependency parsing and other usages.	|
| ResponseDependency	| Model-based dependency parsing results for the dialogue responses. The data organizations are the same as the ProfileDependency.	|

## DEFINITIONS OF CONSISTENCY RELATIONS
* **ENTAILED**: The response is exactly talking about the dialogue agent’s attribute information, and the attribute is consistent with its key-value proﬁle.
* **CONTRADICTED**: Although the response is talking about the dialogue agent’s attribute information, it is contradicted to at least one of the given key-value pairs. For example, given the proﬁle “{location: Beijing}”, “I am in Seattle” is contradicted to the proﬁle, while “She lives in Seattle” is not, because the latter is not talking about the dialogue agent’s attribute.
* **IRRELEVANT**: The response contains proﬁle-related information, but the information does not reveal the dialogue agent’s own attributes. As exempliﬁed above, “She lives in Seattle” is irrelevant, rather than contradicted, to the dialogue agent’s proﬁle “{location: Beijing}”. Another example is “I’m interested in the history of Beijing”. Although there is the attribute word “Beijing”, this response still does not reveal the dialogue agent’s location.

## CITATION
* If the dataset is of help to your works, please cite the following paper:

	<pre>
	@inproceedings{song-2020-kvpi,
	    title = {Profile Consistency Identiﬁcation for Open-domain Dialogue Agents},
	    author = {Song, Haoyu and Wang, Yan and Zhang, Wei-Nan and Zhao, Zhengyu and Liu, Ting and Liu, Xiaojiang},
	    booktitle = {Proceedings of the 2020 Conference on Empirical Methods in Natural Language Processing},
	    month = {November},
	    year = {2020},
	    publisher = {Association for Computational Linguistics},
	}
	</pre>